/*******************************************************************************
*  Berzerk.h - Main object to process log files
*
*  Berzerk/
*
*  Part of the BuckoSoft Network Monitor
*  Copyright 2009 - BuckoSoft, Inc.
*
*  http://cvs.buckosoft.com/Projects/Berzerk/Berzerk/Berzerk/Berzerk.h
*
*  $Id: Berzerk.h,v 1.6 2009/10/13 02:23:47 dick Exp $
*
*  With which we monitor a log file and perform appropriate action.
\*******************************************************************************/

/*
 *  $Log: Berzerk.h,v $
 *  Revision 1.6  2009/10/13 02:23:47  dick
 *  Add daemonMode.
 *  Start work on programmable traps.
 *
 *  Revision 1.5  2009/10/10 23:54:09  dick
 *  Add writePidFile().
 *
 *  Revision 1.4  2009/10/06 04:19:26  dick
 *  Try to open the config file in the current directory,
 *  and if that fails then look in the configured sysconfdir.
 *
 *  Revision 1.3  2009/10/05 07:55:34  dick
 *  Add the badguyIP map.  Log our doings.
 *
 *  Revision 1.2  2009/10/04 07:27:24  dick
 *  Parse the global config file.
 *
 *  Revision 1.1  2009/09/29 00:28:03  dick
 *  Rename LogProc to Berzerk.
 *  Rename Config to Filter.
 *
 *  Revision 1.2  2009/09/28 23:20:58  dick
 *  Add attributes ipTables, bSyslog, and dryRun.
 *
 *  Revision 1.1  2009/09/27 23:57:46  dick
 *  LogProc becomes an object.
 *
 */

#ifndef	_BERZERK_H_
#define	_BERZERK_H_

#include <string>
#include <fstream>
#include <map>

//#include <boost/regex.hpp>

#include "Filter.h"
#include "Config.h"
#include "LogWriter.h"
#include "Statistics.h"

using namespace std;
using namespace boost;

///////////////////////////////////////////////////////////////////////////////
class LogFile {
public:
	string		name;
	ifstream	stream;
	int			pos;

};


///////////////////////////////////////////////////////////////////////////////
namespace berzerk {

using namespace statistics;

class Berzerk {

public:
	Berzerk();

	void	usage();

	int		parseCommandLine(int argc,  _TCHAR* argv[]);
	void	prepareRegexp();
	void	writePidFile();
	int		openLogFiles();
	int		run();

	void	setTailMode(bool value);	// After reading the file, stick around a la "tail -f"
	bool	isTailMode() const;

	void	addFilter(Filter* filter);
	void	addTrap(const string& name, const string& trap);

	void	setIpTables(bool value);
	bool	isIpTables() const;

	void	setSyslog(bool value);
	bool	isSyslog() const;

	void	setDryRun(bool value);
	bool	isDryRun() const;

	void	setDaemonMode(bool value);
	bool	isDaemonMode() const;

	void	setServerAddress(const string& addr);
	const string& getServerAddress() const;

	void	setServerPort(const string& port);
	void	setServerPort(int port);
	const string&	getServerPort() const;

	Statistics&		getStatistics();

private:
	bool	lineMatched(Filter* filter, const string& line, const regex& ipPattern, const regex* triggered);

	list<Filter*>	filters;
	list<LogFile*>	logFiles;
	bool			tailMode;
	bool			ipTables;
	bool			bSyslog;
	bool			dryRun;
	bool			daemonMode;
	Config			config;
	LogWriter		log;
	map<string,string>	trapMap;
	map<string,int>	badguyMap;

	// For the http server
	string			serverAddress;
	string			serverPort;
	Statistics		statistics;
};

inline void Berzerk::setTailMode(bool value) { tailMode = value; };
inline bool	Berzerk::isTailMode() const { return(tailMode); }
inline void Berzerk::setIpTables(bool value) { ipTables = value; };
inline bool	Berzerk::isIpTables() const { return(ipTables); }
inline void Berzerk::setSyslog(bool value) { bSyslog = value; };
inline bool	Berzerk::isSyslog() const { return(bSyslog); }
inline void Berzerk::setDryRun(bool value) { dryRun = value; };
inline bool	Berzerk::isDryRun() const { return(dryRun); }
inline void Berzerk::setDaemonMode(bool value) { daemonMode = value; };
inline bool	Berzerk::isDaemonMode() const { return(daemonMode); }
inline void Berzerk::addFilter(Filter* c) { filters.push_back(c); }
inline void Berzerk::addTrap(const string& n, const string& t) { trapMap[n] = t; }
inline void Berzerk::setServerAddress(const string& a) { serverAddress = a; }
inline const string& Berzerk::getServerAddress() const { return(serverAddress); }
inline void Berzerk::setServerPort(const string& s) {serverPort = s; }
inline const string& Berzerk::getServerPort() const { return(serverPort); }
inline Statistics& Berzerk::getStatistics() { return(statistics); }
extern	Berzerk	berzerk;
}

#endif	// _BERZERK_H_
