/*******************************************************************************
*  Filter.h - Configure the program
*
*  Berzerk/
*
*  Part of the BuckoSoft Network Monitor
*  Copyright 2008 - BuckoSoft, Inc.
*
*  http://cvs.buckosoft.com/Projects/Berzerk/Berzerk/Berzerk/Filter.h
*
*  $Id: Filter.h,v 1.6 2009/10/13 02:24:43 dick Exp $
*
*  With which we monitor a log file and perform appropriate action.
\*******************************************************************************/

/*
 *  $Log: Filter.h,v $
 *  Revision 1.6  2009/10/13 02:24:43  dick
 *  Handle the "trap" command.
 *
 *  Revision 1.5  2009/10/06 04:19:26  dick
 *  Try to open the config file in the current directory,
 *  and if that fails then look in the configured sysconfdir.
 *
 *  Revision 1.4  2009/10/05 07:53:45  dick
 *  Add attribute weight.  How bad is this offense?
 *
 *  Revision 1.3  2009/10/04 07:26:23  dick
 *  Commentality.
 *
 *  Revision 1.2  2009/10/04 01:02:52  dick
 *  Dynamic debug.
 *
 *  Revision 1.1  2009/09/29 00:28:03  dick
 *  Rename LogProc to Berzerk.
 *  Rename Config to Filter.
 *
 *  Revision 1.6  2009/09/28 23:12:28  dick
 *  ipTables is not an attribute of Config.
 *
 *  Revision 1.5  2009/09/27 23:59:48  dick
 *  Add support for multiple Configs in one file.
 *
 *  Revision 1.4  2008/05/27 05:11:02  dick
 *  isIpTables() is const
 *
 *  Revision 1.3  2008/05/25 07:38:26  dick
 *  LogProc builds and runs on Linux.
 *
 *  Revision 1.2  2008/05/22 01:42:14  dick
 *  Support multiple matches
 *
 *  Revision 1.1  2008/05/20 08:08:12  dick
 *  Configure the LogProc application
 *
 */

#ifndef	_FILTER_H_
#define	_FILTER_H_

#include <string>
#include <list>
using namespace std;

#include <boost/regex.hpp>
using namespace boost;

//namespace berzerk { class Berzerk; }

class Filter
{
  public:
	Filter();
  public:
	~Filter();

	static bool	parseFile(PCSTR fileName);

	void	setName(const string& name);
	const string& getName();

	void	setTrap(const string& trap);
	const string& getTrap();

	void	setLogFile(const string& logFile);
	const string& getLogFile();

	void	setWeight(int weight);
	int		getWeight();
	bool	readFile(ifstream& ifs);

	const	list<string>& getMatchPatterns();
	const	string& getIPPattern();
	void	prepareRegexp();

	//void	setBerzerk(Berzerk* berzerk);
	static void	setDEBUG(int value);
	list<regex*> 	patterns;

  private:
	string			name;
	list<string>	matchPatterns;
	string			ipExtractPattern;
	string			logFile;
	string			trap;
	int				weight;

	static int		DEBUG;
};

inline const list<string>& Filter::getMatchPatterns() { return(matchPatterns); }
inline const string& Filter::getIPPattern() { return(ipExtractPattern); }

inline void Filter::setLogFile(const string& lf) { logFile = lf; }
inline const string& Filter::getLogFile() { return(logFile); }

inline void Filter::setName(const string& n) { name = n; }
inline const string& Filter::getName() { return(name); }

inline void Filter::setTrap(const string& t) { trap = t; }
inline const string& Filter::getTrap() { return(trap); }

inline void Filter::setWeight(int w) { weight = w; }
inline int Filter::getWeight() { return(weight); }

inline void Filter::setDEBUG(int level) { DEBUG = level; }

#endif		// _FILTER_H_
