/*******************************************************************************
*  StatServer.cpp - Serve up the Statistics
*
*  Berzerk/
*
*  Part of the BuckoSoft Network Monitor
*  Copyright 2011 - BuckoSoft, Corp.
*
\*******************************************************************************/

#include "stdafx.h"
#include "../config.h"
#include <iostream>

#if 0
#include <xercesc/util/PlatformUtils.hpp>
#include <xercesc/util/XMLString.hpp>
#include <xercesc/dom/DOM.hpp>
#include <xercesc/util/OutOfMemoryException.hpp>
#endif

#include <boost/lexical_cast.hpp>

#include "server/reply.hpp"

#include "StatServer.h"

using namespace http::server;

#if 0
using namespace xercesc;
#endif

//-----------------------------------------------------------------------------


namespace berzerk {

static PCSTR	s_public_statistics = "/public/statistics";

string toXml(PCSTR element, int value) {
	string s = "<";
	s += element;
	s += ">";
	s += boost::lexical_cast<std::string>(value);
	s += "</";
	s += element;
	s += ">";
	return(s);
}
const char crlf[] = { '\r', '\n', 0};

reply::status_type		StatServer::handleRequest(const  std::string& uri, http::server::reply& rep) {
	if (uri == "/public")
		return(doIndex(rep));
	if (uri.compare(0, strlen(s_public_statistics), s_public_statistics) == 0)
		return(doStatistics(uri.substr(strlen(s_public_statistics)), rep));
	return(reply::not_implemented);
}

reply::status_type		StatServer::doIndex(reply& rep) {
	rep.content += "LinesRead: ";
	rep.content += boost::lexical_cast<std::string>(statistics->getLinesRead());
	rep.content += crlf;
	rep.content += "IPsKilled: ";
	rep.content += boost::lexical_cast<std::string>(statistics->getIPsKilled());
	//rep.content += crlf;
	rep.content_type = reply::plain;
	return(reply::ok);

}

reply::status_type		StatServer::doStatistics(string args, reply& rep) {
	int count = 10;
	int	i;
	if (args.length() > 0 && args[0] == '?') {
		count = atoi(args.substr(1).c_str());
	}
	rep.content_type = reply::xml;
	rep.content += "<?xml version=\"1.0\" encoding=\"iso-8859-1\"?>";
	rep.content += crlf;
	rep.content += "<statistics><overview>";
	rep.content += toXml("linesRead", statistics->getLinesRead());
	rep.content += toXml("ipsKilled", statistics->getIPsKilled());
	rep.content += "</overview>";
	statistics->lock();
	list<StatLine*>::iterator it;
	for (it=statistics->statLines.begin(), i=0; it != statistics->statLines.end() && i < count; it++, i++) {
		StatLine* sl = *it;
		rep.content += sl->toXML();
	}
	statistics->unlock();
	rep.content += "</statistics>";
	return(reply::ok);
}

}	// namespace berzerk
